#-----------------------------------------------------------------------
# File    : somd.mak
# Contents: build self-organizing map visualization
# Author  : Christian Borgelt
# History : 2003.01.28 file created
#           2006.07.20 adapted to Visual Studio 8
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR = ..\..\somd\src
UTILDIR = ..\..\util\src
DRAWDIR = ..\..\draw\src

CC      = cl.exe
DEFS    = /D WIN32 /D NDEBUG /D _WINDOWS /D _CRT_SECURE_NO_WARNINGS
CFLAGS  = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS    = /I $(UTILDIR) /I $(DRAWDIR)

RSC     = rc.exe
RFLAGS  = /l 0x407 /d NDEBUG

LD      = link.exe
LDFLAGS = /nologo /subsystem:windows /incremental:no
LIBS    = user32.lib comdlg32.lib gdi32.lib

HDRS    = $(UTILDIR)\random.h   $(DRAWDIR)\proj3d.h   \
          somd.h wsom.rh
OBJS    = $(UTILDIR)\random.obj $(DRAWDIR)\proj3d.obj \
          somd.obj wsom.obj wsom.res
PRGS    = wsom.exe

#-----------------------------------------------------------------------
# Build Program
#-----------------------------------------------------------------------
all:          wsom.exe

wsom.exe:     $(OBJS)
	$(LD) $(LDFLAGS) $(OBJS) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Program
#-----------------------------------------------------------------------
wsom.obj:     $(DRAWDIR)\proj3d.h somd.h wsom.rh wsom.c somd.mak
	$(CC) $(CFLAGS) $(INCS) wsom.c /Fo$@

somd.obj:     $(UTILDIR)\random.h $(DRAWDIR)\proj3d.h \
              somd.h somd.c somd.mak
	$(CC) $(CFLAGS) $(INCS) /D SOM_DRAW somd.c /Fo$@

#-----------------------------------------------------------------------
# Resources
#-----------------------------------------------------------------------
wsom.res:     wsom.rh wsom.rc somd.mak
	$(RSC) $(RFLAGS) /fo$@ wsom.rc

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(DRAWDIR)\proj3d.obj:
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak proj3d.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy $(PRGS) ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f somd.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak clean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch *.res $(PRGS)
